==> dde-session-shell_6.0.21.tar.xz: BUILD/translations/dde-session-shell_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Face ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verification successful</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation>
            <numerusform>Verification failed, %n chances left</numerusform>
            <numerusform>Verification failed, %n chances left</numerusform>
        </translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verification failed, only one chance left</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Verify your Face ID</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Face ID locked, use password please</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verify your fingerprint</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verification successful</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation>
            <numerusform>Verification failed, %n chances left</numerusform>
            <numerusform>Verification failed, %n chances left</numerusform>
        </translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verification failed, only one chance left</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Fingerprint locked, use password please</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Iris ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verification successful</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation>
            <numerusform>Verification failed, %n chances left</numerusform>
            <numerusform>Verification failed, %n chances left</numerusform>
        </translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verification failed, only one chance left</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Verify your Iris ID</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Iris ID locked, use password please</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verification successful</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation>
            <numerusform>Verification failed, %n chances left</numerusform>
            <numerusform>Verification failed, %n chances left</numerusform>
        </translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verification failed, only one chance left</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Wrong Password</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Please try again 1 minute later</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation>
            <numerusform>Please try again %n minutes later</numerusform>
            <numerusform>Please try again %n minutes later</numerusform>
        </translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Reset Password</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Forgot password?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Please try again 1 minute later</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation>
            <numerusform>Please try again %n minutes later</numerusform>
            <numerusform>Please try again %n minutes later</numerusform>
        </translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Reset Password</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Forgot password?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verification successful</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation>
            <numerusform>Verification failed, %n chances left</numerusform>
            <numerusform>Verification failed, %n chances left</numerusform>
        </translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verification failed, only one chance left</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Wrong PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey is required</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Enter your PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation>
            <numerusform>Please try again %n minute(s) later</numerusform>
            <numerusform>Please try again %n minute(s) later</numerusform>
        </translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Please try again 1 minute later</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation>
            <numerusform>Please try again %n minutes later</numerusform>
            <numerusform>Please try again %n minutes later</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Account</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation>
            <numerusform>Your password will expire in %n days, please change it timely</numerusform>
            <numerusform>Your password will expire in %n days, please change it timely</numerusform>
        </translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Password expired, please change</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation type="unfinished">Wrong account</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished">Wrong Password</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Lock Screen</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Failed to lock screen</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Fingerprint verification timed out, please enter your password manually</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Failed to match fingerprint</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Shut down</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reboot</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspend</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernate</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Lock</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Log out</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Switch user</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Switch system</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Start system monitor</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>To close the program, click Cancel, and then close the program.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>The programs are preventing the computer from log out, and forcing log out may cause data loss.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Shut down</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reboot</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspend</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernate</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Log out</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Are you sure you want to shut down?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Are you sure you want to reboot?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Are you sure you want to log out?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Turn on</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Turn off</translation>
    </message>
</context>
</TS>

==> dde-session-shell_6.0.41.tar.xz: BUILD/translations/dde-session-shell_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Face ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verification successful</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation>
            <numerusform>Verification failed, %n chances left</numerusform>
            <numerusform>Verification failed, %n chances left</numerusform>
        </translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verification failed, only one chance left</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Verify your Face ID</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Face ID locked, use password please</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Device unavailable!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verify your fingerprint</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verification successful</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation>
            <numerusform>Verification failed, %n chances left</numerusform>
            <numerusform>Verification failed, %n chances left</numerusform>
        </translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verification failed, only one chance left</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Fingerprint locked, use password please</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Iris ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verification successful</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation>
            <numerusform>Verification failed, %n chances left</numerusform>
            <numerusform>Verification failed, %n chances left</numerusform>
        </translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verification failed, only one chance left</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Verify your Iris ID</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Iris ID locked, use password please</translation>
    </message>
</context>
<context>
    <name>AuthPasskey</name>
    <message>
        <source>Please plug in the security key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished">Verification successful</translation>
    </message>
    <message>
        <source>Verification failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Identifying the security key</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verification successful</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation>
            <numerusform>Verification failed, %n chances left</numerusform>
            <numerusform>Verification failed, %n chances left</numerusform>
        </translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verification failed, only one chance left</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Wrong Password</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Please try again 1 minute later</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation>
            <numerusform>Please try again %n minutes later</numerusform>
            <numerusform>Please try again %n minutes later</numerusform>
        </translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Reset Password</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Forgot password?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Please try again 1 minute later</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation>
            <numerusform>Please try again %n minutes later</numerusform>
            <numerusform>Please try again %n minutes later</numerusform>
        </translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Reset Password</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Forgot password?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verification successful</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation>
            <numerusform>Verification failed, %n chances left</numerusform>
            <numerusform>Verification failed, %n chances left</numerusform>
        </translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verification failed, only one chance left</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Wrong PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey is required</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Enter your PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation>
            <numerusform>Please try again %n minute(s) later</numerusform>
            <numerusform>Please try again %n minute(s) later</numerusform>
        </translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Please try again 1 minute later</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation>
            <numerusform>Please try again %n minutes later</numerusform>
            <numerusform>Please try again %n minutes later</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Account</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation>
            <numerusform>Your password will expire in %n days, please change it timely</numerusform>
            <numerusform>Your password will expire in %n days, please change it timely</numerusform>
        </translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Password expired, please change</translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it</source>
        <translation>Your password has expired. Please contact the administrator to change it</translation>
    </message>
    <message>
        <source>Terminal locked, please contact administrator</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeepinAuthFramework</name>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished">Wrong Password</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Wrong account</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Wrong Password</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>The reason of inhibit.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LighterGreeter</name>
    <message>
        <source>Standard Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Lock Screen</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Failed to lock screen</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Fingerprint verification timed out, please enter your password manually</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Failed to match fingerprint</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Shut down</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reboot</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspend</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernate</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Lock</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Log out</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Switch user</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Switch system</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Start system monitor</translation>
    </message>
</context>
<context>
    <name>UdcpMFALoginWidget</name>
    <message>
        <source>发送验证码</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>请输入手机号</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>请输入验证码</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>获取验证码</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UsersWithTheSameName</name>
    <message>
        <source>Return</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please select the account for login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Local Account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Domain Account</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>To close the program, click Cancel, and then close the program.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>The programs are preventing the computer from log out, and forcing log out may cause data loss.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Shut down</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reboot</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspend</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernate</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Log out</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Are you sure you want to shut down?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Are you sure you want to reboot?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Are you sure you want to log out?</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Closing the programs and shutting down, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Closing the programs and rebooting, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Closing the programs and logging out, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dss::module::AssistLoginWidget</name>
    <message>
        <source>Automatic login</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Turn on</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Turn off</translation>
    </message>
</context>
</TS>
